.. highlight:: shell

============
Installation
============


Stable release
--------------

You can install xarray-leaflet with pip:

.. code-block:: console

    $ pip install xarray_leaflet

Or with conda (or mamba):

.. code-block:: console

    $ conda install xarray_leaflet


From sources
------------

The sources for xarray-leaflet can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/davidbrochart/xarray_leaflet

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/davidbrochart/xarray_leaflet/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ pip install .


.. _Github repo: https://github.com/davidbrochart/xarray_leaflet
.. _tarball: https://github.com/davidbrochart/xarray_leaflet/tarball/master
